==> openshift-model-operator-5.0.2-sources.jar: annotations/io/fabric8/openshift/api/model/operator/v1/DNSRecordListFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;

public class DNSRecordListFluentImpl<A extends DNSRecordListFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements DNSRecordListFluent<A> {

    private String apiVersion;
    private List<DNSRecordBuilder> items =  new ArrayList<DNSRecordBuilder>();
    private String kind;
    private ListMeta metadata;

    public DNSRecordListFluentImpl() {
    }

    public DNSRecordListFluentImpl(DNSRecordList instance) {
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion() {
        return this.apiVersion;
    }

    public A withApiVersion(String apiVersion) {
        this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion() {
        return this.apiVersion != null;
    }

    public A withNewApiVersion(String arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuilder arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A addToItems(int index,DNSRecord item) {
        if (this.items == null) {this.items = new ArrayList<DNSRecordBuilder>();}
        DNSRecordBuilder builder = new DNSRecordBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,DNSRecord item) {
        if (this.items == null) {this.items = new ArrayList<DNSRecordBuilder>();}
        DNSRecordBuilder builder = new DNSRecordBuilder(item);
        if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
        if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
         return (A)this;
    }

    public A addToItems(DNSRecord... items) {
        if (this.items == null) {this.items = new ArrayList<DNSRecordBuilder>();}
        for (DNSRecord item : items) {DNSRecordBuilder builder = new DNSRecordBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<DNSRecord> items) {
        if (this.items == null) {this.items = new ArrayList<DNSRecordBuilder>();}
        for (DNSRecord item : items) {DNSRecordBuilder builder = new DNSRecordBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(DNSRecord... items) {
        for (DNSRecord item : items) {DNSRecordBuilder builder = new DNSRecordBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<DNSRecord> items) {
        for (DNSRecord item : items) {DNSRecordBuilder builder = new DNSRecordBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromItems(Predicate<DNSRecordBuilder> predicate) {
        if (items == null) return (A) this;
        final Iterator<DNSRecordBuilder> each = items.iterator();
        final List visitables = _visitables.get("items");
        while (each.hasNext()) {
          DNSRecordBuilder builder = each.next();
          if (predicate.test(builder)) {
            visitables.remove(builder);
            each.remove();
          }
        }
        return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<DNSRecord> getItems() {
        return build(items);
    }

    public List<DNSRecord> buildItems() {
        return build(items);
    }

    public DNSRecord buildItem(int index) {
        return this.items.get(index).build();
    }

    public DNSRecord buildFirstItem() {
        return this.items.get(0).build();
    }

    public DNSRecord buildLastItem() {
        return this.items.get(items.size() - 1).build();
    }

    public DNSRecord buildMatchingItem(Predicate<DNSRecordBuilder> predicate) {
        for (DNSRecordBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingItem(Predicate<DNSRecordBuilder> predicate) {
        for (DNSRecordBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withItems(List<DNSRecord> items) {
        if (this.items != null) { _visitables.get("items").removeAll(this.items);}
        if (items != null) {this.items = new ArrayList<DNSRecordBuilder>(); for (DNSRecord item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
    }

    public A withItems(DNSRecord... items) {
        if (this.items != null) {this.items.clear();}
        if (items != null) {for (DNSRecord item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems() {
        return items != null && !items.isEmpty();
    }

    public DNSRecordListFluent.ItemsNested<A> addNewItem() {
        return new ItemsNestedImpl();
    }

    public DNSRecordListFluent.ItemsNested<A> addNewItemLike(DNSRecord item) {
        return new ItemsNestedImpl(-1, item);
    }

    public DNSRecordListFluent.ItemsNested<A> setNewItemLike(int index,DNSRecord item) {
        return new ItemsNestedImpl(index, item);
    }

    public DNSRecordListFluent.ItemsNested<A> editItem(int index) {
        if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
        return setNewItemLike(index, buildItem(index));
    }

    public DNSRecordListFluent.ItemsNested<A> editFirstItem() {
        if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
        return setNewItemLike(0, buildItem(0));
    }

    public DNSRecordListFluent.ItemsNested<A> editLastItem() {
        int index = items.size() - 1;
        if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
        return setNewItemLike(index, buildItem(index));
    }

    public DNSRecordListFluent.ItemsNested<A> editMatchingItem(Predicate<DNSRecordBuilder> predicate) {
        int index = -1;
        for (int i=0;i<items.size();i++) { 
        if (predicate.test(items.get(i))) {index = i; break;}
        } 
        if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
        return setNewItemLike(index, buildItem(index));
    }

    public String getKind() {
        return this.kind;
    }

    public A withKind(String kind) {
        this.kind=kind; return (A) this;
    }

    public Boolean hasKind() {
        return this.kind != null;
    }

    public A withNewKind(String arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuilder arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1) {
        return (A)withKind(new String(arg1));
    }

    public ListMeta getMetadata() {
        return this.metadata;
    }

    public A withMetadata(ListMeta metadata) {
        this.metadata=metadata; return (A) this;
    }

    public Boolean hasMetadata() {
        return this.metadata != null;
    }

    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
        return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        DNSRecordListFluentImpl that = (DNSRecordListFluentImpl) o;
        if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
        if (items != null ? !items.equals(that.items) :that.items != null) return false;
        if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
        if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
    }

    public class ItemsNestedImpl<N> extends DNSRecordFluentImpl<DNSRecordListFluent.ItemsNested<N>> implements DNSRecordListFluent.ItemsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final DNSRecordBuilder builder;
        private final int index;

            ItemsNestedImpl(int index,DNSRecord item) {
                this.index = index;
                this.builder = new DNSRecordBuilder(this, item);
                        
            }

            ItemsNestedImpl() {
                this.index = -1;
                this.builder = new DNSRecordBuilder(this);
                        
            }

            public N and() {
                return (N) DNSRecordListFluentImpl.this.setToItems(index,builder.build());
            }

            public N endItem() {
                return and();
            }
    }


}

==> openshift-model-operator-5.3.1-sources.jar: annotations/io/fabric8/openshift/api/model/operator/v1/DNSRecordListFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;

public class DNSRecordListFluentImpl<A extends DNSRecordListFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements DNSRecordListFluent<A> {

    private String apiVersion;
    private List<DNSRecordBuilder> items =  new ArrayList<DNSRecordBuilder>();
    private String kind;
    private ListMeta metadata;

    public DNSRecordListFluentImpl() {
    }

    public DNSRecordListFluentImpl(DNSRecordList instance) {
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
    }

    public String getApiVersion() {
        return this.apiVersion;
    }

    public A withApiVersion(String apiVersion) {
        this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion() {
        return this.apiVersion != null;
    }

    public A withNewApiVersion(StringBuilder arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(int[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(char[] arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(StringBuffer arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(byte[] arg1,int arg2) {
        return (A)withApiVersion(new String(arg1, arg2));
    }

    public A withNewApiVersion(byte[] arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A withNewApiVersion(char[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(byte[] arg1,int arg2,int arg3) {
        return (A)withApiVersion(new String(arg1, arg2, arg3));
    }

    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withApiVersion(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewApiVersion(String arg1) {
        return (A)withApiVersion(new String(arg1));
    }

    public A addToItems(int index,DNSRecord item) {
        if (this.items == null) {this.items = new ArrayList<DNSRecordBuilder>();}
        DNSRecordBuilder builder = new DNSRecordBuilder(item);_visitables.get("items").add(index >= 0 ? index : _visitables.get("items").size(), builder);this.items.add(index >= 0 ? index : items.size(), builder); return (A)this;
    }

    public A setToItems(int index,DNSRecord item) {
        if (this.items == null) {this.items = new ArrayList<DNSRecordBuilder>();}
        DNSRecordBuilder builder = new DNSRecordBuilder(item);
        if (index < 0 || index >= _visitables.get("items").size()) { _visitables.get("items").add(builder); } else { _visitables.get("items").set(index, builder);}
        if (index < 0 || index >= items.size()) { items.add(builder); } else { items.set(index, builder);}
         return (A)this;
    }

    public A addToItems(DNSRecord... items) {
        if (this.items == null) {this.items = new ArrayList<DNSRecordBuilder>();}
        for (DNSRecord item : items) {DNSRecordBuilder builder = new DNSRecordBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A addAllToItems(Collection<DNSRecord> items) {
        if (this.items == null) {this.items = new ArrayList<DNSRecordBuilder>();}
        for (DNSRecord item : items) {DNSRecordBuilder builder = new DNSRecordBuilder(item);_visitables.get("items").add(builder);this.items.add(builder);} return (A)this;
    }

    public A removeFromItems(DNSRecord... items) {
        for (DNSRecord item : items) {DNSRecordBuilder builder = new DNSRecordBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeAllFromItems(Collection<DNSRecord> items) {
        for (DNSRecord item : items) {DNSRecordBuilder builder = new DNSRecordBuilder(item);_visitables.get("items").remove(builder);if (this.items != null) {this.items.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromItems(Predicate<DNSRecordBuilder> predicate) {
        if (items == null) return (A) this;
        final Iterator<DNSRecordBuilder> each = items.iterator();
        final List visitables = _visitables.get("items");
        while (each.hasNext()) {
          DNSRecordBuilder builder = each.next();
          if (predicate.test(builder)) {
            visitables.remove(builder);
            each.remove();
          }
        }
        return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<DNSRecord> getItems() {
        return build(items);
    }

    public List<DNSRecord> buildItems() {
        return build(items);
    }

    public DNSRecord buildItem(int index) {
        return this.items.get(index).build();
    }

    public DNSRecord buildFirstItem() {
        return this.items.get(0).build();
    }

    public DNSRecord buildLastItem() {
        return this.items.get(items.size() - 1).build();
    }

    public DNSRecord buildMatchingItem(Predicate<DNSRecordBuilder> predicate) {
        for (DNSRecordBuilder item: items) { if(predicate.test(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingItem(Predicate<DNSRecordBuilder> predicate) {
        for (DNSRecordBuilder item: items) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withItems(List<DNSRecord> items) {
        if (this.items != null) { _visitables.get("items").removeAll(this.items);}
        if (items != null) {this.items = new ArrayList<DNSRecordBuilder>(); for (DNSRecord item : items){this.addToItems(item);}} else { this.items = null;} return (A) this;
    }

    public A withItems(DNSRecord... items) {
        if (this.items != null) {this.items.clear();}
        if (items != null) {for (DNSRecord item :items){ this.addToItems(item);}} return (A) this;
    }

    public Boolean hasItems() {
        return items != null && !items.isEmpty();
    }

    public io.fabric8.openshift.api.model.operator.v1.DNSRecordListFluent.ItemsNested<A> addNewItem() {
        return new ItemsNestedImpl();
    }

    public io.fabric8.openshift.api.model.operator.v1.DNSRecordListFluent.ItemsNested<A> addNewItemLike(DNSRecord item) {
        return new ItemsNestedImpl(-1, item);
    }

    public io.fabric8.openshift.api.model.operator.v1.DNSRecordListFluent.ItemsNested<A> setNewItemLike(int index,DNSRecord item) {
        return new ItemsNestedImpl(index, item);
    }

    public io.fabric8.openshift.api.model.operator.v1.DNSRecordListFluent.ItemsNested<A> editItem(int index) {
        if (items.size() <= index) throw new RuntimeException("Can't edit items. Index exceeds size.");
        return setNewItemLike(index, buildItem(index));
    }

    public io.fabric8.openshift.api.model.operator.v1.DNSRecordListFluent.ItemsNested<A> editFirstItem() {
        if (items.size() == 0) throw new RuntimeException("Can't edit first items. The list is empty.");
        return setNewItemLike(0, buildItem(0));
    }

    public io.fabric8.openshift.api.model.operator.v1.DNSRecordListFluent.ItemsNested<A> editLastItem() {
        int index = items.size() - 1;
        if (index < 0) throw new RuntimeException("Can't edit last items. The list is empty.");
        return setNewItemLike(index, buildItem(index));
    }

    public io.fabric8.openshift.api.model.operator.v1.DNSRecordListFluent.ItemsNested<A> editMatchingItem(Predicate<DNSRecordBuilder> predicate) {
        int index = -1;
        for (int i=0;i<items.size();i++) { 
        if (predicate.test(items.get(i))) {index = i; break;}
        } 
        if (index < 0) throw new RuntimeException("Can't edit matching items. No match found.");
        return setNewItemLike(index, buildItem(index));
    }

    public String getKind() {
        return this.kind;
    }

    public A withKind(String kind) {
        this.kind=kind; return (A) this;
    }

    public Boolean hasKind() {
        return this.kind != null;
    }

    public A withNewKind(StringBuilder arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(int[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(char[] arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(StringBuffer arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(byte[] arg1,int arg2) {
        return (A)withKind(new String(arg1, arg2));
    }

    public A withNewKind(byte[] arg1) {
        return (A)withKind(new String(arg1));
    }

    public A withNewKind(char[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(byte[] arg1,int arg2,int arg3) {
        return (A)withKind(new String(arg1, arg2, arg3));
    }

    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withKind(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewKind(String arg1) {
        return (A)withKind(new String(arg1));
    }

    public ListMeta getMetadata() {
        return this.metadata;
    }

    public A withMetadata(ListMeta metadata) {
        this.metadata=metadata; return (A) this;
    }

    public Boolean hasMetadata() {
        return this.metadata != null;
    }

    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink) {
        return (A)withMetadata(new ListMeta(_continue, remainingItemCount, resourceVersion, selfLink));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        DNSRecordListFluentImpl that = (DNSRecordListFluentImpl) o;
        if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
        if (items != null ? !items.equals(that.items) :that.items != null) return false;
        if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
        if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(apiVersion,  items,  kind,  metadata,  super.hashCode());
    }

    public class ItemsNestedImpl<N> extends DNSRecordFluentImpl<io.fabric8.openshift.api.model.operator.v1.DNSRecordListFluent.ItemsNested<N>> implements io.fabric8.openshift.api.model.operator.v1.DNSRecordListFluent.ItemsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final DNSRecordBuilder builder;
        private final int index;

            ItemsNestedImpl(int index,DNSRecord item) {
                this.index = index;
                this.builder = new DNSRecordBuilder(this, item);
                        
            }

            ItemsNestedImpl() {
                this.index = -1;
                this.builder = new DNSRecordBuilder(this);
                        
            }

            public N and() {
                return (N) DNSRecordListFluentImpl.this.setToItems(index,builder.build());
            }

            public N endItem() {
                return and();
            }
    }


}
